==> ejc-jlincome-api-3.0.0-20240723.064147-201-sources.jar: com/ejianc/business/jlincome/performance/vo/SaleReportByMonthVO.java <==
package com.ejianc.business.jlincome.performance.vo;

import com.ejianc.foundation.share.utils.ITreeNodeB;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * @author 胡子龙
 * @date 2024/6/18 17:17
 **/
public class SaleReportByMonthVO extends BaseVO implements ITreeNodeB {
    private static final long serialVersionUID = 1L;

    private Long parentId; // 父级Id
    private Long orgId; // 区域ID
    private String orgCode; // 区域code
    private String orgName; // 区域名称
    private Long teamOrgId; // 小组区域ID
    private String teamOrgCode; // 小组区域code
    private String teamOrgName; // 小组区域名称
    private Long employeeId; // 负责人ID
    private String employeeName; // 负责人
    private String year; // 年度

    private BigDecimal saleYearTaskMny; // 销售_全年任务
    private BigDecimal saleEndThisMouth; // 截止本月完成
    private BigDecimal saleThisMouth; // 本月完成

    private BigDecimal kpYearTaskMny; // 开票_全年任务
    private BigDecimal kpEndThisMouth; // 截止本月完成
    private BigDecimal kpThisMouth; // 本月完成

    private BigDecimal skYearTaskMny; // 开票_全年任务
    private BigDecimal skEndThisMouth; // 截止本月完成
    private BigDecimal skThisMouth; // 本月完成
    private List<ITreeNodeB> children;
    @Override
    public Long getNodeID() {
        return getId();
    }

    @Override
    public Long getParentID() {
        return parentId;
    }

    @Override
    public List<ITreeNodeB> getChildren() {
        if (children == null) {
            children = new ArrayList<>();
        }
        return children;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getTeamOrgId() {
        return teamOrgId;
    }

    public void setTeamOrgId(Long teamOrgId) {
        this.teamOrgId = teamOrgId;
    }

    public String getTeamOrgCode() {
        return teamOrgCode;
    }

    public void setTeamOrgCode(String teamOrgCode) {
        this.teamOrgCode = teamOrgCode;
    }

    public String getTeamOrgName() {
        return teamOrgName;
    }

    public void setTeamOrgName(String teamOrgName) {
        this.teamOrgName = teamOrgName;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }

    public void setChildren(List<ITreeNodeB> children) {
        this.children = children;
    }

    public BigDecimal getSaleYearTaskMny() {
        return saleYearTaskMny;
    }

    public void setSaleYearTaskMny(BigDecimal saleYearTaskMny) {
        this.saleYearTaskMny = saleYearTaskMny;
    }

    public BigDecimal getSaleEndThisMouth() {
        return saleEndThisMouth;
    }

    public void setSaleEndThisMouth(BigDecimal saleEndThisMouth) {
        this.saleEndThisMouth = saleEndThisMouth;
    }

    public BigDecimal getSaleThisMouth() {
        return saleThisMouth;
    }

    public void setSaleThisMouth(BigDecimal saleThisMouth) {
        this.saleThisMouth = saleThisMouth;
    }

    public BigDecimal getKpYearTaskMny() {
        return kpYearTaskMny;
    }

    public void setKpYearTaskMny(BigDecimal kpYearTaskMny) {
        this.kpYearTaskMny = kpYearTaskMny;
    }

    public BigDecimal getKpEndThisMouth() {
        return kpEndThisMouth;
    }

    public void setKpEndThisMouth(BigDecimal kpEndThisMouth) {
        this.kpEndThisMouth = kpEndThisMouth;
    }

    public BigDecimal getKpThisMouth() {
        return kpThisMouth;
    }

    public void setKpThisMouth(BigDecimal kpThisMouth) {
        this.kpThisMouth = kpThisMouth;
    }

    public BigDecimal getSkYearTaskMny() {
        return skYearTaskMny;
    }

    public void setSkYearTaskMny(BigDecimal skYearTaskMny) {
        this.skYearTaskMny = skYearTaskMny;
    }

    public BigDecimal getSkEndThisMouth() {
        return skEndThisMouth;
    }

    public void setSkEndThisMouth(BigDecimal skEndThisMouth) {
        this.skEndThisMouth = skEndThisMouth;
    }

    public BigDecimal getSkThisMouth() {
        return skThisMouth;
    }

    public void setSkThisMouth(BigDecimal skThisMouth) {
        this.skThisMouth = skThisMouth;
    }
}

==> ejc-jlincome-api-3.0.0-20241115.080528-371-sources.jar: com/ejianc/business/jlincome/performance/vo/SaleReportByMonthVO.java <==
package com.ejianc.business.jlincome.performance.vo;

import com.ejianc.foundation.share.utils.ITreeNodeB;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * @author 胡子龙
 * @date 2024/6/18 17:17
 **/
public class SaleReportByMonthVO extends BaseVO implements ITreeNodeB {
    private static final long serialVersionUID = 1L;

    private Long parentId; // 父级Id
    private Long orgId; // 区域ID
    private String orgCode; // 区域code
    private String orgName; // 区域名称
    private Long teamOrgId; // 小组区域ID
    private String teamOrgCode; // 小组区域code
    private String teamOrgName; // 小组区域名称
    private Long employeeId; // 负责人ID
    private String employeeName; // 负责人
    private String year; // 年度

    private BigDecimal saleYearTaskMny; // 销售_全年任务
    private BigDecimal saleEndThisMouth; // 截止本月完成
    private BigDecimal saleYearUnComplete; // 本年完成差距
    private BigDecimal saleYearCompleteScale; // 本年完成百分比
    private BigDecimal saleThisMouth; // 本月完成

    private BigDecimal kpYearTaskMny; // 开票_全年任务
    private BigDecimal kpEndThisMouth; // 截止本月完成
    private BigDecimal kpYearUnComplete; // 本年完成差距
    private BigDecimal kpYearCompleteScale; // 本年完成百分比
    private BigDecimal kpThisMouth; // 本月完成

    private BigDecimal skYearTaskMny; // 开票_全年任务
    private BigDecimal skEndThisMouth; // 截止本月完成
    private BigDecimal skYearUnComplete; // 本年完成差距
    private BigDecimal skYearCompleteScale; // 本年完成百分比
    private BigDecimal skThisMouth; // 本月完成
    private List<ITreeNodeB> children;


    public BigDecimal getSaleYearUnComplete() {
        return saleYearUnComplete;
    }

    public void setSaleYearUnComplete(BigDecimal saleYearUnComplete) {
        this.saleYearUnComplete = saleYearUnComplete;
    }

    public BigDecimal getSaleYearCompleteScale() {
        return saleYearCompleteScale;
    }

    public void setSaleYearCompleteScale(BigDecimal saleYearCompleteScale) {
        this.saleYearCompleteScale = saleYearCompleteScale;
    }

    public BigDecimal getKpYearUnComplete() {
        return kpYearUnComplete;
    }

    public void setKpYearUnComplete(BigDecimal kpYearUnComplete) {
        this.kpYearUnComplete = kpYearUnComplete;
    }

    public BigDecimal getKpYearCompleteScale() {
        return kpYearCompleteScale;
    }

    public void setKpYearCompleteScale(BigDecimal kpYearCompleteScale) {
        this.kpYearCompleteScale = kpYearCompleteScale;
    }

    public BigDecimal getSkYearUnComplete() {
        return skYearUnComplete;
    }

    public void setSkYearUnComplete(BigDecimal skYearUnComplete) {
        this.skYearUnComplete = skYearUnComplete;
    }

    public BigDecimal getSkYearCompleteScale() {
        return skYearCompleteScale;
    }

    public void setSkYearCompleteScale(BigDecimal skYearCompleteScale) {
        this.skYearCompleteScale = skYearCompleteScale;
    }

    @Override
    public Long getNodeID() {
        return getId();
    }

    @Override
    public Long getParentID() {
        return parentId;
    }

    @Override
    public List<ITreeNodeB> getChildren() {
        if (children == null) {
            children = new ArrayList<>();
        }
        return children;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getTeamOrgId() {
        return teamOrgId;
    }

    public void setTeamOrgId(Long teamOrgId) {
        this.teamOrgId = teamOrgId;
    }

    public String getTeamOrgCode() {
        return teamOrgCode;
    }

    public void setTeamOrgCode(String teamOrgCode) {
        this.teamOrgCode = teamOrgCode;
    }

    public String getTeamOrgName() {
        return teamOrgName;
    }

    public void setTeamOrgName(String teamOrgName) {
        this.teamOrgName = teamOrgName;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }

    public void setChildren(List<ITreeNodeB> children) {
        this.children = children;
    }

    public BigDecimal getSaleYearTaskMny() {
        return saleYearTaskMny;
    }

    public void setSaleYearTaskMny(BigDecimal saleYearTaskMny) {
        this.saleYearTaskMny = saleYearTaskMny;
    }

    public BigDecimal getSaleEndThisMouth() {
        return saleEndThisMouth;
    }

    public void setSaleEndThisMouth(BigDecimal saleEndThisMouth) {
        this.saleEndThisMouth = saleEndThisMouth;
    }

    public BigDecimal getSaleThisMouth() {
        return saleThisMouth;
    }

    public void setSaleThisMouth(BigDecimal saleThisMouth) {
        this.saleThisMouth = saleThisMouth;
    }

    public BigDecimal getKpYearTaskMny() {
        return kpYearTaskMny;
    }

    public void setKpYearTaskMny(BigDecimal kpYearTaskMny) {
        this.kpYearTaskMny = kpYearTaskMny;
    }

    public BigDecimal getKpEndThisMouth() {
        return kpEndThisMouth;
    }

    public void setKpEndThisMouth(BigDecimal kpEndThisMouth) {
        this.kpEndThisMouth = kpEndThisMouth;
    }

    public BigDecimal getKpThisMouth() {
        return kpThisMouth;
    }

    public void setKpThisMouth(BigDecimal kpThisMouth) {
        this.kpThisMouth = kpThisMouth;
    }

    public BigDecimal getSkYearTaskMny() {
        return skYearTaskMny;
    }

    public void setSkYearTaskMny(BigDecimal skYearTaskMny) {
        this.skYearTaskMny = skYearTaskMny;
    }

    public BigDecimal getSkEndThisMouth() {
        return skEndThisMouth;
    }

    public void setSkEndThisMouth(BigDecimal skEndThisMouth) {
        this.skEndThisMouth = skEndThisMouth;
    }

    public BigDecimal getSkThisMouth() {
        return skThisMouth;
    }

    public void setSkThisMouth(BigDecimal skThisMouth) {
        this.skThisMouth = skThisMouth;
    }
}
